#include <ESP8266WiFi.h>

//....................... Параметры WIFI ............................
const char* ssid = "xxxxxxxxxxxxxx";  // Введите имя WIFI сети
const char* password = "xxxxxxxx";    // Введите пароль WIFI сети
WiFiClient client;

//...................... Параметры сервиса ThingsPeak ...............
const char* server = "api.thingspeak.com"; 
String apiKey = "xxxxxxxxxxxxxxx";   // Введите API key thingspeak

//...................... Датчик DHT22 (DHT11) .......................
#include <DHT.h>
#define DHTPIN 12                     // Порт подключения датчика DHT22 или DHT11,
#define DHTTYPE DHT22                 // Тип датчика: DHT22 или DHT11
DHT dht(DHTPIN, DHTTYPE);

//...................... Дисплей .....................................
#include "SH1106Wire.h"
#include "Wire.h"
#include "WeatherStationFonts.h"
const int I2C_DISPLAY_ADDRESS = 0x3c;
const int SDA_PIN = 0;                // Порт ESP8266 для подключения SDA индикатора
const int SDC_PIN = 2;                // Порт ESP8266 для подключения SCL индикатора 
SH1106Wire     display(I2C_DISPLAY_ADDRESS, SDA_PIN, SDC_PIN);

 //=======================================================================
void setup() 
{     
  Serial.begin(115200);
  delay(10);
  Serial.println();
  //................Подключение к WIFI сети......................
  WiFi.mode(WIFI_STA);
  Serial.println();
  Serial.print("Connecting to ");
  Serial.println(ssid);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) 
  {
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.println("WiFi connected");
  Serial.println("IP address: ");
  Serial.println(WiFi.localIP());
//...................... Инициализация Дисплея ..................
  display.init();           
  display.clear();
  display.flipScreenVertically();
  display.setFont(ArialMT_Plain_16);
  display.setContrast(255);
  display.drawString(0,10, " Weather Sensor\n         DHT22\n    elshema.info");
  display.display();

  //.......................DHT...................................
  dht.begin();
}

//================================================================

void loop() 
{
  display.clear(); 
 //.........................DHT...................................
  float h = dht.readHumidity();
  float t = dht.readTemperature();
  if (isnan(h) || isnan(t)) 
  {
    Serial.println("Failed to read from DHT sensor!");
    return;
  }
 
  if (client.connect(server,80)) 
  {  
    String postStr = apiKey;
           postStr +="&field6=";
           postStr += String(t);
           postStr +="&field7=";
           postStr += String(h);
           postStr += "\r\n\r\n";

     Serial.print("Sending data: ");
     Serial.println(postStr);
 
     client.print("POST /update HTTP/1.1\n"); 
     client.print("Host: api.thingspeak.com\n"); 
     client.print("Connection: close\n"); 
     client.print("X-THINGSPEAKAPIKEY: "+apiKey+"\n"); 
     client.print("Content-Type: application/x-www-form-urlencoded\n"); 
     client.print("Content-Length: "); 
     client.print(postStr.length()); 
     client.print("\n\n"); 
     client.print(postStr);
           
     Serial.print("Temperature: ");
     Serial.print(t);
     Serial.print(" degrees Celcius Humidity: "); 
     Serial.print(h);
     Serial.println("% send to Thingspeak");
     
     display.setFont(ArialMT_Plain_24);
     display.drawString(18, 10,String(t));
     display.drawString(80, 10,"°C");
     display.drawString(18, 40,String(h));
     display.drawString(82, 40,"%");       
     display.display(); 
  }
  client.stop();
   
  Serial.println("Waiting...");                                           
  for(unsigned int i = 0; i < 20; i++)    // thingspeak необходимо задержка между обновлениями минимум 15 сек.
  {
    delay(3000);                         
  }
}
